## v0.6.0 (2025-02-05)

### ✨ Features

- add ArrAccessor for getting fit_arr values (#18)
- add visualization of fit stat to DisplayAccessor (#17)

## v0.5.0 (2025-02-05)

### ✨ Features

- implement auto-estimating initial coords for fit_with_corr method (#14)

## v0.4.0 (2025-02-05)

### ✨ Features

- add y-axis fix toggle for display accessor  (#13)

## v0.3.0 (2025-02-04)

### ✨ Features

- add fit_with_correlation method for FitAccessor (#12)

## v0.2.0 (2025-02-03)

### ✨ Features

- add params and display accessor (#10)

## v0.1.0 (2025-01-30)
